16.15. cdist-type__cdistmarker(7) — cdist 6.9.4 documentation

# 16.15. cdist-type__cdistmarker(7)

## 16.15.1. NAME

cdist-type__cdistmarker - Add a timestamped cdist marker.

## 16.15.2. DESCRIPTION

This type is used to add a common marker file which indicates that a given machine is being managed by cdist. The contents of this file consist of a timestamp, which can be used to determine the most recent time at which cdist was run against the machine in question.

## 16.15.3. REQUIRED PARAMETERS

None.

## 16.15.4. OPTIONAL PARAMETERS

destination

  The path and filename of the marker. Default: /etc/cdist-configured

format

  The format of the timestamp. This is passed directly to system 'date'. Default: -u

## 16.15.5. EXAMPLES

    # Creates the marker as normal.
    __cdistmarker

    # Creates the marker differently.
    __cdistmarker --destination /tmp/cdist_marker --format '+%s'

## 16.15.6. AUTHORS

Daniel Maher <phrawzty+cdist--@--gmail.com>

## 16.15.7. COPYING

Copyright (C) 2011 Daniel Maher. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.